@@ -177,9 +177,9 @@ stat.table <- function(index, contents=count(), data, margins=FALSE)
     ulim <- tab.dim + ifelse(in.subtable,rep(0,n.dim),rep(1, n.dim))
     subindex <- index[in.subtable]
     subtable.list <- if(missing(data))
-      eval(contents)
+      eval(contents, parent.frame())
     else
-      eval(as.expression(contents),data)
+      eval(as.expression(contents), data)
     for (j in 1:length(subtable.list)) {
       ans[array.subset(ans.dim,c(j,llim),c(j,ulim))] <- subtable.list[[j]]
     }
